@@ -147,7 +147,7 @@ class TemplateAction(deskbar.interfaces.Action):
                     return
 
             shutil.copyfile(self.template_file.uri, created_file)
-            subprocess.Popen(["gnome-open", created_file])
+            deskbar.core.Utils.url_show_file("file://%s" % created_file)
 
         dialog.destroy()
 
@@ -187,14 +187,20 @@ class TemplateHandler(deskbar.interfaces.Module):
     def _templates_dir_monitor_cb(self, monitor, file, other_file, event_type):
         self._add_template_file(file.get_path())
  
-    def initialize(self):
-        templates_dir = deskbar.core.Utils.get_xdg_user_dir(deskbar.core.Utils.DIRECTORY_TEMPLATES)
-
+    def _add_templates_dir(self, templates_dir):
         for f in os.listdir(templates_dir):
             # Skip backup files and hidden files
             if f.endswith("~") or f.startswith("."):
                 continue
-            self._add_template_file(os.path.join(templates_dir, f))
+            file_path = os.path.join(templates_dir, f)
+            if os.path.isdir(file_path):
+                self._add_templates_dir(file_path)
+            else:
+                self._add_template_file(file_path)
+ 
+    def initialize(self):
+        templates_dir = deskbar.core.Utils.get_xdg_user_dir(deskbar.core.Utils.DIRECTORY_TEMPLATES)
+        self._add_templates_dir(templates_dir)
 
         gfile = gio.File(path=templates_dir)
         try:
@@ -213,4 +219,20 @@ class TemplateHandler(deskbar.interfaces.Module):
     def stop(self):
         for filemonitor in self.monitors:
             filemonitor.cancel()
-    
\ No newline at end of file
+            
+    @staticmethod
+    def has_requirements():
+        # Work around bug #577649
+        try:
+            templates_dir = deskbar.core.Utils.get_xdg_user_dir(deskbar.core.Utils.DIRECTORY_TEMPLATES)
+        except ValueError, e:
+            LOGGER.exception(e)
+            TemplateHandler.INSTRUCTIONS = _("Could not retrieve templates directory")
+            return False
+
+        if os.path.exists(templates_dir):
+            return True
+        else:
+           TemplateHandler.INSTRUCTIONS = _("Templates directory %s does not exist") % templates_dir
+           return False
+    
